changeset 1075:0fe8eda4f002

Teach hello world native build to honor $FTP_SERVER
author Rob Landley <rob@landley.net>
date Fri, 14 May 2010 01:57:22 -0500
parents dd5be60a2794
children 9a7b5e73e6ea
files sources/native-builds/hello-world.sh
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/sources/native-builds/hello-world.sh	Fri May 14 01:56:15 2010 -0500
+++ b/sources/native-builds/hello-world.sh	Fri May 14 01:57:22 2010 -0500
@@ -24,10 +24,10 @@
 gcc -lpthread /usr/src/thread-hello2.c -o hello &&
 ./hello
 
 # Upload our hello world file to the output directory (named hello-$ARCH).
 # No reason, just an example.
 
-ftpput 10.0.2.2 -P $OUTPORT hello-"$ARCH" hello
+ftpput $FTP_SERVER -P $FTP_PORT hello-$HOST hello
 
 sync
@@ -24,10 +24,10 @@
 ./hello
 
-# Upload our hello world file to the output directory (named hello-$ARCH).
+# Upload our hello world file to the output directory (named hello-$HOST).
 # No reason, just an example.
 